# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['flyingsnake']

package_data = \
{'': ['*']}

install_requires = \
['Pillow>=6.1.0,<7.0.0', 'click>=7.0,<8.0', 'lihzahrd>=2.0.0a1,<3.0.0']

entry_points = \
{'console_scripts': ['flyingsnake = flyingsnake.__main__:flyingsnake']}

setup_kwargs = {
    'name': 'flyingsnake',
    'version': '2.0.0a2',
    'description': 'A Terraria world map renderer',
    'long_description': "# ![](https://gamepedia.cursecdn.com/terraria_gamepedia/8/82/Flying_Snake.png?version=2b0351f579d721166af80a12d2c2e325) `flyingsnake` [![](https://img.shields.io/pypi/v/flyingsnake)](https://pypi.org/project/flyingsnake/) ![](https://img.shields.io/badge/maintenance-passively--maintained-yellowgreen)\n\nRender Terraria world maps with this easy to use command line utility!\n\n![flyingsnake Small_Example.wld Output.png](https://i.imgur.com/HtNEIKw.png)\n\n## Requirements\n\nTo use `flyingsnake`, you need [Python 3.7 or higher](https://www.python.org/downloads/) installed on your machine and inside your PATH.\n\n## Installing\n\n`flyingsnake` is available on PyPI, so you can download it through `pip`. \n\n### Windows\n\nOpen either **Windows PowerShell** (Windows 10) or the **Command Prompt** (other Windows versions) and enter:\n\n```batch\npip install flyingsnake --upgrade\n```\n\n### Linux\n\nEnter this in your terminal:\n\n```bash\npython3.7 -m pip install flyingsnake --upgrade\n```\n\n## Usage\n\nTo create a world map image named `Output.png` from the `Small_Example.wld` file present in your current working directory, run in your terminal:\n\n```bash\nflyingsnake Small_Example.wld Output.png\n```\n\n### Layers\n\nThe world map is generated by merging together multiple layers that can be enabled/disabled through flags.\n\nIn order, those are:\n- Background\n- Walls\n- Liquids\n- Blocks\n- Wires\n\n#### Background\n\nThe background layer is made by coloring the Overworld, the Underground and the Caverns their respective background color.\n\nIt can be selected exclusively with the `--background` flag, or turned off with the `--no-background` flag.\n\n![flyingsnake Small_Example.wld Output.png --background](https://i.imgur.com/69qRLZX.png)\n\n#### Walls\n\nThe walls layer contains the colors of the walls present in the world.\n\nIt can be selected exclusively with the `--walls` flag, or turned off with the `--no-walls` flag.\n\nIf the walls are painted, they will be colored with the paint color.\nYou can turn off paint colors with the `--no-paints` option.\n\n![flyingsnake Small_Example.wld Output.png --walls](https://i.imgur.com/Grkq5PQ.png)\n\n#### Liquids\n\nThe liquids layer contains the colors of the liquids present in the world (water, lava, honey...)\n\nIt can be selected exclusively with the `--liquids` flag, or turned off with the `--no-liquids` flag.\n\n![flyingsnake Small_Example.wld Output.png --liquids](https://i.imgur.com/Pifjb4D.png)\n\n#### Blocks\n\nThe blocks layer contains the colors of the blocks present in the world.\n\nIt can be selected exclusively with the `--blocks` flag, or turned off with the `--no-blocks` flag.\n\nIf the blocks are painted, they will be colored with the paint color.\nYou can turn off paint colors with the `--no-paints` option.\n\n![flyingsnake Small_Example.wld Output.png --blocks](https://i.imgur.com/E05kgOA.png)\n\n#### Wires\n\nThe wires layer is a semi-transparent overlay of the wires present in the world.\n\nIt can be selected exclusively with the `--wires` flag, or turned off with the `--no-wires` flag.\n\n![flyingsnake Small_Example.wld Output.png --wires](https://i.imgur.com/XDLRCAE.png)\n\n### Custom colors\n\nBy default, `flyingsnake` uses the colors defined in the [TEdit settings file](https://github.com/TEdit/Terraria-Map-Editor/blob/master/TEditXna/settings.xml).\n\nHowever, you can use different colors by passing the `--colors colors.json` option to the command.\n\nYou can see an example colors file [here](https://github.com/Steffo99/flyingsnake/tree/master/flyingsnake/example_colors.json); the colors are in RGBA format, and go from 0 to 255.\n\n## License\n\n`flyingsnake` is licensed under the [AGPL 3.0](/LICENSE.txt).\nBasically, you're allowed to do whatever you want with this program, but you have to publish all modified code, and it has to be published under the same license.\n\n## See also\n\nIf you are interested in `flyingsnake`, you might be interested in these other programs too:\n\n- [lihzahrd](https://github.com/Steffo99/lihzahrd), the package used to make this generator\n- [TEdit](https://github.com/TEdit/Terraria-Map-Editor), the Terraria map editor from which this package gets its default colors\n",
    'author': 'Stefano Pigozzi',
    'author_email': 'ste.pigozzi@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Steffo99/flyingsnake',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
